@@ -4,4 +4,6 @@ from .mintlayer import  MINTLayer
 from .mintterminal import MINTTerminal
 from .mintconnection import MINTConnection
 from .mintcomponent import MINTComponent
-from .mintcompiler import MINTCompiler
\ No newline at end of file
+from .mintcompiler import MINTCompiler
+from .mintdevice import MINTDevice
+from .mintnode import MINTNode
\ No newline at end of file
