@@ -1,5 +1,5 @@
 from pymint.constraints.constraint import LayoutConstraint
-from typing import overload
+from typing import Dict, overload
 from pymint.mintcomponent import MINTComponent
 from parchmint.component import Component
 from enum import Enum
@@ -11,9 +11,12 @@ class ComponentOrientation(Enum):
 class OrientationConstraint(LayoutConstraint):
     def __init__(self) -> None:
         super().__init__()
-        self.__orientation_map = dict()
+        self.__orientation_map: Dict[MINTComponent, ComponentOrientation] = dict()
 
     def add_component(self, component:MINTComponent, orientation:ComponentOrientation )->None:
         super().add_component(component)
         self.__orientation_map[component] = orientation
 
+    @property
+    def orientation_map(self) -> Dict[MINTComponent, ComponentOrientation]:
+        return self.__orientation_map
