@@ -1,3 +1,4 @@
+from __future__ import annotations
 from pymint.mintparams import MINTParams
 from parchmint.connection import Connection
 from pymint.minttarget import MINTTarget
@@ -18,6 +19,6 @@ class MINTConnection(Connection):
     def overwrite_id(self, id: str) -> None:
         self.ID = id
 
-    def toMINT(self) -> str:
-        ret = "{} {} from {} to {} {} ;".format(self.entity, self.name, self.source.toMINT(), " ".join([item.toMINT() for item in self.sinks]), self.params.toMINT())
-        return ret
\ No newline at end of file
+    def to_MINT(self) -> str:
+        ret = "{} {} from {} to {} {} ;".format(self.entity, self.name, self.source.to_MINT(), " ".join([item.to_MINT() for item in self.sinks]), self.params.to_MINT())
+        return ret
