@@ -1,5 +1,6 @@
 from parchmint.layer import Layer
 
+
 from enum import Enum
 
 class MINTLayerType(Enum):
@@ -26,7 +27,7 @@ class MINTLayer(Layer):
         self.name = "{}_{}".format(str(layer_type), id)
         self.type = str(layer_type)
 
-    def toMINT(self, content:str) -> str:
+    def to_MINT(self, content:str) -> str:
         
         ret = "LAYER {} \n\n{} \n\nEND LAYER".format(self.type, content)
         return ret
