@@ -10,4 +10,7 @@ class MINTTerminal(MINTComponent):
     @property
     def port_number(self) -> int:
         return self.__port_number
+    
+    def to_MINT(self) -> str:
+        return "TERMINAL {} {}".format(self.name, self.__port_number)
     
\ No newline at end of file
